from javaman.connexio import JManCon


class Proveidors:
    __slots__ = '_con'

    _url_list_proveidors = '/proveidors/llista'
    _url_proveidors = '/proveidors'
    _url_get_proveidor = '/proveidors/{proveidor_id}'
    _url_put_proveidor = '/proveidors/{proveidor_id}'

    def __init__(self, con: JManCon):
        self._con = con

    def list_proveidors(self):
        res = self._con.get(url=self._url_list_proveidors)
        return res.json()

    def get_proveidor_by_nif(self, p_nif: str):
        res = self._con.get(url=self._url_proveidors+'?nif='+p_nif)
        return res.json()

    def get_proveidor(self, proveidor_id: int):
        res = self._con.get(url=self._url_get_proveidor.format(proveidor_id=str(proveidor_id)))
        return res.json()

    def post_proveidor(self, proveidor: dict):
        res = self._con.post(url=self._url_proveidors, data=proveidor)
        return res.json()

    def put_proveidor(self, proveidor_id: int, proveidor: dict):
        res = self._con.post(url=self._url_put_proveidor.format(proveidor_id=str(proveidor_id)), data=proveidor)
        return res.json()



from javaman.connexio import JManCon


class Recepcions:
    __slots__ = '_con'

    _url_proveidors = '/recepcions/proveidors'
    _url_proveidor = '/recepcions/proveidors/{proveidor_id}'
    _url_proveidor_articles = '/recepcions/proveidors/{proveidor_id}/articles'
    _url_proveidor_comanda = '/recepcions/proveidors/{proveidor_id}/comandes_compra'
    _url_proveidor_comanda_art = '/recepcions/proveidors/{proveidor_id}/comandes_compra?article_atribut_id={article_atribut_id}'

    _url_post_recepcions = '/recepcions'
    _url_post_unitat_logistica = '/recepcions/{recepcio_id}/unitat_logistica'
    _url_post_unitat_logistica_mag = '/recepcions/{recepcio_id}/magatzem/{magatzem_id}/unitat_logistica'
    _url_post_unitat_logistica_mag_com = '/recepcions/{recepcio_id}/comanda/{comanda_compra_id}/magatzem/{magatzem_id}/unitat_logistica'
    _url_post_finalitzar = '/recepcions/{recepcio_id}/finalitzar'


    def __init__(self, con: JManCon):
        self._con = con

    def list_proveidors(self):
        res = self._con.get(url=self._url_proveidors)
        return res.json()

    def get_proveidor(self, proveidor_id: int):
        res = self._con.get(url=self._url_proveidor.format(proveidor_id=str(proveidor_id)))
        return res.json()

    def get_comandes_compra(self, proveidor_id: int, article_atribut_id: int = None):
        if article_atribut_id is None:
            res = self._con.get(url=self._url_proveidor_comanda.format(proveidor_id=str(proveidor_id)))
        else:
            res = self._con.get(url=self._url_proveidor_comanda_art.format(proveidor_id=str(proveidor_id), article_atribut_id=article_atribut_id))
        return res.json()

    def get_articles(self, proveidor_id: int):
        res = self._con.get(url=self._url_proveidor_articles.format(proveidor_id=str(proveidor_id)))
        return res.json()

    def post_recepcio(self, recepcio: dict):
        res = self._con.post(url=self._url_post_recepcions, data=recepcio)
        return res.json()

    def post_unitat_logistica(self, recepcio_id: int,  unitat_logistica: dict, magatzem_id: int = None, comanda_compra_id: int = None):
        if magatzem_id is None and comanda_compra_id is None:
            tmp_url = self._url_post_unitat_logistica.format(recepcio_id=recepcio_id)
        elif comanda_compra_id is None and magatzem_id is not None:
            tmp_url = self._url_post_unitat_logistica_mag.format(recepcio_id=recepcio_id, magatzem_id=magatzem_id)
        else:
            tmp_url = self._url_post_unitat_logistica_mag_com.format(recepcio_id=recepcio_id, magatzem_id=magatzem_id, comanda_compra_id=comanda_compra_id)

        res = self._con.post(url=tmp_url, data=unitat_logistica)
        return res.json()

    def post_finalitzar(self, recepcio_id: int, dades_albara: dict):
        res = self._con.post(url=self._url_post_finalitzar.format(recepcio_id=recepcio_id), data=dades_albara)
        return res.json()



from javaman.connexio import JManCon

class PuntsVenda:
    __slots__ = '_con'

    _url_get_punt_venda = '/punts_venda/{punt_venda_id}'

    def __init__(self, con: JManCon):
        self._con = con

    def get_punt_venda(self, punt_venda_id: int):
        res = self._con.get(url=self._url_get_punt_venda.format(punt_venda_id=str(punt_venda_id)))
        return res.json()


from javaman.connexio import JManCon


class Empreses:
    __slots__ = '_con'

    _url_get_empresa = '/empreses?empresa_id={empresa_id}'

    def __init__(self, con: JManCon):
        self._con = con

    def get_empresa_by_id(self, p_empresa_id: int):
        tmp_url = self._url_get_empresa.format(empresa_id=p_empresa_id)
        req = self._con.get(url=tmp_url)
        return req.json()



from javaman.connexio import JManCon


class Tercers:
    __slots__ = '_con'

    _url_get_tercers = '/tercer'
    _url_get_tercers_parametres = '/tercer/{id_tercer}/parametres'
    _url_get_tercers_anotacions = '/tercer/{id_tercer}/anotacions'
    _url_get_tercers_bancs = '/tercers_bancs'
    _url_get_tercer_banc = '/tercers_bancs/{tercer_banc_id}'

    def __init__(self, con: JManCon):
        self._con = con

    def get_tercer(self, p_tercer: int):
        req = self._con.get(url=self._url_get_tercers+'/'+str(p_tercer))
        return req.json()

    def get_tercer_by_nif(self, p_nif: str):
        req = self._con.get(url=self._url_get_tercers+'?nif='+p_nif)
        return req.json()

    def get_tercer_parametres(self, p_tercer: int):
        req = self._con.get(url=Tercers._url_get_tercers_parametres.format(id_tercer=p_tercer))
        return req.json()

    def get_tercer_anotacions(self, p_tercer: int):
        req = self._con.get(url=Tercers._url_get_tercers_anotacions.format(id_tercer=p_tercer))
        return req.json()

    def get_tercers_bancs_by_id(self, p_tercer_banc_id: int):
        req = self._con.get(url=Tercers._url_get_tercer_banc.format(tercer_banc_id=p_tercer_banc_id))
        return req.json()

    def get_tercers_bancs_by_tercer_id(self, p_tercer_id: int):
        req = self._con.get(url=Tercers._url_get_tercers_bancs+'?tercer_id='+str(p_tercer_id))
        return req.json()
